Crate i18n_format_macro

Crate i18n_format_macro 

Implement the proc macros.

Macros

i18n_fmt
Wrapper macro to use allow formatting with gettext and ngettext in a way that allow xgettext to find strings for .po files as it doesn’t support a keyword with a !.