Crate i18n_format_macro
i18n_
format_
macro
0.4.0
All Items
Crate Items
Macros
Crate
i18n_
format_
macro
Implement the proc macros.
Macros

i18n_
fmt
Wrapper macro to use allow formatting with gettext and ngettext in a way that allow xgettext to find strings for
.po
files as it doesn’t support a keyword with a
!
.